
class UploadController < ApplicationController

  before_filter :authorize

  def index
  end

  def upload_nike_xml
    require 'rexml/document'
    require 'time'
        
    xml_file = params[:xml_doc][:xml_file]
    xml_doc = REXML::Document.new(xml_file.read)
    root = xml_doc.root

    if root.elements["vers"][0] != 2
      flash.now[:notice] = "Wrong version of Nike XML data"
      redirect_to(:controller => 'upload', :action => 'index')
    end

    #OK, time to make a run object that contains all the crazy info in this XML doc
    @run = Run.new
    @run.user_id = session[:user_id]
    @run.start_time = Time.xmlschema(root.elements["runSummary/time"][0].value) #Start time of run
    @run.duration = root.elements["runSummary/duration"][0].value #Duration in ms
    @run.playlist = root.elements["runSummary/playlistList/playlist/playlistName"][0].value unless root.elements["runSummary/playlistList/playlist/playlistName"].nil? # Playlist name
    @run.weight = root.elements["userInfo/weight"][0].value
    @run.device = root.elements["userInfo/device"][0].value
    @run.calibration = root.elements["userInfo/calibration"][0].value

    #run_distance = root.elements["runSummary/distance"][0].value
    #run_distance_units = root.elements["runSummary/distance"].attributes["unit"]
    @run.save

    #Make a snapshot object for each snapshot in the run (mile/km splits, pause, resume, etc)
    root.elements.each("snapShotList[@snapShotType='kmSplit']/snapShot") do |element| 
      @snapshot = SnapShot.new
      @snapshot.run_id = @run.id
      @snapshot.snapshot_type = 'kmSplit'
      @snapshot.duration = element.elements["duration"][0].value
      @snapshot.distance = element.elements["distance"][0].value
      @snapshot.pace = element.elements["pace"][0].value
      @snapshot.save
    end

    root.elements.each("snapShotList[@snapShotType='mileSplit']/snapShot") do |element| 
      @snapshot = SnapShot.new
      @snapshot.run_id = @run.id
      @snapshot.snapshot_type = 'mileSplit'
      @snapshot.duration = element.elements["duration"][0].value
      @snapshot.distance = element.elements["distance"][0].value
      @snapshot.pace = element.elements["pace"][0].value
      @snapshot.save
    end

    root.elements.each("snapShotList[@snapShotType='userClick']/snapShot") do |element| 
      @snapshot = SnapShot.new
      @snapshot.run_id = @run.id
      @snapshot.snapshot_type = 'userClick'
      @snapshot.event_type = element.attributes["event"]
      @snapshot.duration = element.elements["duration"][0].value
      @snapshot.distance = element.elements["distance"][0].value
      @snapshot.pace = element.elements["pace"][0].value
      @snapshot.save
    end

    #Save extended data (splits at 10 second intervals)
    @extendeddata = ExtendedData.new
    @extendeddata.run_id = @run.id
    @extendeddata.data_type = root.elements["extendedDataList/extendedData"].attributes["dataType"]
    @extendeddata.interval_type = root.elements["extendedDataList/extendedData"].attributes["intervalType"]
    @extendeddata.interval_unit = root.elements["extendedDataList/extendedData"].attributes["intervalUnit"]
    @extendeddata.interval_value = root.elements["extendedDataList/extendedData"].attributes["intervalValue"]
    @extendeddata.extended_data = root.elements["extendedDataList/extendedData"][0].value
    @extendeddata.save

    #render :action => index
  end
end
