require 'digest/sha1'

class User < ActiveRecord::Base

  
  has_many :runs
  has_many :snap_shots, :through => :runs
  has_many :extended_datas, :through => :runs

  validates_presence_of :user_name
  validates_presence_of :first_name
  validates_presence_of :last_name
  validates_presence_of :email_address
  validates_presence_of :birth_date
  
  validates_length_of :user_name, :within => 3...40
  validates_length_of :email_address, :within => 3...100
  validates_uniqueness_of :user_name, :case_sensitive => false
  validates_uniqueness_of :email_address, :case_sensitive => false
  
  attr_accessor :password_confirmation
  validates_confirmation_of :password

  def validate
    errors.add_to_base('Missing password') if hashed_password.blank?
  end

  #Age in years
  def age
    ((Time.now - birth_date.to_time).seconds / 31556926).floor
  end

  #Auth user. If the password hashes don't match returns nil
  def self.authenticate(user_name, password)
    user = self.find_by_user_name(user_name)
    if user
      expected_hash = encrypted_password(password, user.salt)
      if user.hashed_password != expected_hash
        user = nil
      end 
    end
    user
  end
  
  def pace
    total_pace = 0
    total_snap_shots = 0

    self.runs.each do |run|
      total_pace += run.pace
      total_runs += 1
    end
    
    return (total_pace/total_runs)/1000 unless total_runs == 0
  end

  def password
    @password
  end
  
  def password=(pwd)
    @password = pwd
    return if pwd.blank?
    create_new_salt
    self.hashed_password = User.encrypted_password(self.password, self.salt)
  end

  private
  
  def self.encrypted_password(password, salt)
    string_to_hash = password + "lulz" + salt #the lulz make it harder to guess the password from the hash & salt
    Digest::SHA1.hexdigest(string_to_hash)
  end
  
  #The salt is based on the user ID and a random number
  def create_new_salt
    self.salt = self.object_id.to_s + rand.to_s
  end
  
end
